@@ -2,6 +2,7 @@ use std::sync::Arc;
 
 use axum::{
     async_trait,
+    body::Body,
     extract::{FromRequest, RequestParts},
 };
 use http::StatusCode;
@@ -13,18 +14,18 @@ use tracing::{field, Span};
 pub struct Extractor(pub AgentId);
 
 #[async_trait]
-impl FromRequest for Extractor {
+impl FromRequest<Body> for Extractor {
     type Rejection = (StatusCode, &'static str);
 
-    async fn from_request(req: &mut RequestParts) -> Result<Self, Self::Rejection> {
+    async fn from_request(req: &mut RequestParts<Body>) -> Result<Self, Self::Rejection> {
         let authn = req
             .extensions()
-            .and_then(|x| x.get::<Arc<AuthnConfig>>())
+            .get::<Arc<AuthnConfig>>()
             .ok_or((StatusCode::UNAUTHORIZED, "No authn config"))?;
 
         let auth_header = req
             .headers()
-            .and_then(|x| x.get("Authorization"))
+            .get("Authorization")
             .and_then(|x| x.to_str().ok())
             .and_then(|x| x.get("Bearer ".len()..))
             .ok_or((StatusCode::UNAUTHORIZED, "Invalid authentication"))?;
